#!/usr/bin/env python3
# encoding: utf-8

import sys
from QRCodeConverter import QRCodeConverter

def parseArgv():
    if len(sys.argv) < 3:
        print("Incorrect args, try:")
        print('./app/run.py ./logo.png "http://github.com"')
        sys.exit(0)

    img_path = sys.argv[1]
    content = sys.argv[2]
    width = sys.argv[3] if len(sys.argv) > 4 and sys.argv[3] else None
    height = sys.argv[4] if len(sys.argv) > 5 and sys.argv[4] else None

    return {
        'img_path': img_path,
        'content': content,
        'size': (width, height)
    }

def handle():
    def successCallback(data):
        pass

    def failureCallback():
        pass

    parser = parseArgv()
    converter = QRCodeConverter()
    converter.set_inner_img_path(parser['img_path'])
    converter.set_qrcode_content(parser['content'])
    converter.set_qrcode_size(parser['size'])
    converter.process(successCallback, failureCallback)

if __name__ == '__main__':
    handle()



#!/usr/bin/env python
# encoding: utf-8

import logging

class Logger(logging.getLoggerClass()):
    __YELLOW = '\033[0;33m%s\033[0m'
    __DARK_RED = '\033[0;41m%s\033[0m'
    __RED = '\033[0;31m%s\033[0m'
    __FORMAT = {
        'fmt': '%(asctime)s %(levelname)s: %(message)s',
        'datefmt': '%Y-%m-%d %H:%M:%S',
    }

    def __init__(self, format=__FORMAT, level=logging.INFO):
        formatter = logging.Formatter(**format)

        self.root.setLevel(level)
        self.root.handlers = []

        handler = logging.StreamHandler()
        handler.setFormatter(formatter)
        self.root.addHandler(handler)

    def critical(self, message):
        self.root.critical(self.__DARK_RED,message)

    def error(self, message):
        self.root.error(self.__RED,message)

    def warn(self, message):
        self.root.warn(self.__YELLOW,message)

    def info(self, message):
        self.root.info(message)

    def debug(self, message):
        self.root.debug(message)

if __name__ == '__main__':
    logger = Logger(level=logging.DEBUG)
    logger.info("This message has default color.")
    logger.debug("This message has default color.")



#!/usr/bin/env python3
# encoding: utf-8

import cStringIO
import urllib
import qrcode
import pdb
from PIL import Image
from util import Util
from log import Logger

class QRCodeConverter:
    def __init__(self):
        self.util = Util()
        self.log = Logger()
        self.block_size = 8
        self.circle_radius = self.block_size * 5
        self.qrcode_img_name_prefix = "qrcode"
        self.qrcode_img_name_surffix = ".png"

    def set_inner_img_path(self, path):
       self.inner_img_path = path

    def set_qrcode_content(self, content):
       self.content = content

    def set_qrcode_size(self, size):
        self.size = size

    def get_qrcode_thumbnail_size(self):
        assert self.size
        assert isinstance(self.size, tuple)
        assert len(self.size) == 2
        assert self.size[0]
        assert self.size[1]

        res_val = max(self.size[0], self.size[1])
        return (res_val, res_val)

    def fetch_file(self, path):
        import os
        if path.startswith('http'):
            f = cStringIO.StringIO(urllib.urlopen(path).read())
        else:
            assert os.path.isfile(path)
            f = cStringIO.StringIO(path)
        return f

    def process(self, successCallback, failureCallback):
        im = qrcode.make(self.content).convert('RGBA')
        outputname = self.qrcode_img_name_prefix + str(self.util.now()) + self.qrcode_img_name_surffix

        try:
            pdb.set_trace()
            inner_img_file = self.fetch_file(self.inner_img_path)
            inner_img = Image.open(inner_img_file).convert('RGBA')

            (width, height) = inner_img.size

            dim = height
            if (width > dim):
                dim = width

            xTrans = (im.size[0] - width) / 2.0
            yTrans = (im.size[1] - dim) / 2.0

            im.paste(inner_img, (int(xTrans), int(yTrans)), inner_img)

            try:
                (img_width, img_height) = get_qrcode_thumbnail_size()
                self.log.debug('Get width and height for qrcode image')
                self.log.debug('Set thunbnail for qrcode with size: (%d, %d)' % (img_width, img_height))
                im.thumbnail(self.size)
            except Exception as thumbnail_exception:
                self.log.debug('Cannot get suitable width and height for qrcode image, do nothing')
        except Exception as e:
            self.log.warn('Cannot fetch inner image with path: %s' %(self.inner_img_path))
            self.log.warn(e)

        im.save(outputname)

        self.log.info("success to process, now call successCallback, qrcode file: " + outputname)
        successCallback(self)



"""
`````````````````
Run it:

.. code:: bash

    $ pip install qrcode-converter
    $ python app/run.py [inner_img_path] [content] [width] [height]
Links
`````

* `website <https://github.com/jackqt/py-qrcode-generator/>`_
* `documentation <https://github.com/jackqt/py-qrcode-generator/>`_

"""
import re
import ast
from setuptools import setup


_version_re = re.compile(r'__version__\s+=\s+(.*)')

with open('app/__init__.py', 'rb') as f:
    version = str(ast.literal_eval(_version_re.search(
        f.read().decode('utf-8')).group(1)))

setup(
    name='qrcode-converter',
    version=version,
    url='https://github.com/jackqt/py-qrcode-generator/',
    license='MIT',
    author='Jack Li',
    author_email='jack.qingtian@gmail.com',
    description='A qrcode generator with inner image',
    long_description=__doc__,
    packages=['app'],
    include_package_data=True,
    zip_safe=False,
    platforms='any',
    install_requires=[
        'Pillow>=4.0.0',
        'qrcode>=5.3'
    ],
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Environment :: Console',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: MIT License',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Topic :: Internet :: WWW/HTTP :: Dynamic Content',
        'Topic :: Software Development :: Libraries :: Python Modules'
    ]
)
